@@ -3,11 +3,11 @@
 # An example of creating an Excel Line chart with a secondary axis
 # using Python and XlsxWriter.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
-workbook = Workbook('chart_secondary_axis.xlsx')
+workbook = xlsxwriter.Workbook('chart_secondary_axis.xlsx')
 worksheet = workbook.add_worksheet()
 bold = workbook.add_format({'bold': 1})
 
