@@ -2,11 +2,11 @@
 #
 # A hello world spreadsheet using the XlsxWriter Python module.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
-workbook = Workbook('hello_world.xlsx')
+workbook = xlsxwriter.Workbook('hello_world.xlsx')
 worksheet = workbook.add_worksheet()
 
 worksheet.write('A1', 'Hello world')
